@@ -76,30 +76,35 @@ static gboolean pe_is_flist( Reduce *rc, PElement *base )
 	{ return( PEISFLIST( base ) ); }
 static gboolean pe_is_class( Reduce *rc, PElement *base )
         { return( PEISCLASS( base ) ); }
-static gboolean pe_is_gobject( Reduce *rc, PElement *base )
-        { return( PEISMANAGEDGOBJECT( base ) ); }
+
 
 /* The types we might want to spot for builtins.
- */
+ *
+ * Others, eg.:
+ *
 static BuiltinTypeSpot vimage_spot = { "vips_image", pe_is_image };
-static BuiltinTypeSpot real_spot = { "real", pe_is_real };
 static BuiltinTypeSpot bool_spot = { "bool", pe_is_bool };
-static BuiltinTypeSpot complex_spot = { "complex|image", iscomplexarg };
-static BuiltinTypeSpot flist_spot = { "non-empty list", pe_is_flist };
 static BuiltinTypeSpot realvec_spot = { "[real]", reduce_is_realvec };
 static BuiltinTypeSpot matrix_spot = { "[[real]]", reduce_is_matrix };
+static BuiltinTypeSpot instance_spot = { "class instance", pe_is_class };
+static gboolean pe_is_gobject( Reduce *rc, PElement *base )
+        { return( PEISMANAGEDGOBJECT( base ) ); }
+static BuiltinTypeSpot gobject_spot = { "GObject", pe_is_gobject };
+ *
+ */
+
+static BuiltinTypeSpot real_spot = { "real", pe_is_real };
+static BuiltinTypeSpot complex_spot = { "complex|image", iscomplexarg };
+static BuiltinTypeSpot flist_spot = { "non-empty list", pe_is_flist };
 static BuiltinTypeSpot string_spot = { "[char]", reduce_is_finitestring };
 static BuiltinTypeSpot list_spot = { "[*]", reduce_is_list };
 static BuiltinTypeSpot math_spot = { "image|real|complex", ismatharg };
-static BuiltinTypeSpot instance_spot = { "class instance", pe_is_class };
 static BuiltinTypeSpot any_spot = { "any", isany };
-static BuiltinTypeSpot gobject_spot = { "GObject", pe_is_gobject };
 
 /* Args for "_".
  */
 static BuiltinTypeSpot *underscore_args[] = {
-        &string_spot,
-        &any_spot
+        &string_spot
 };
 
 /* Do a _ call. Args already spotted.
@@ -345,6 +350,61 @@ apply_read_call( Reduce *rc,
 		reduce_throw( rc );
 }
 
+/* Args for "graph_export_image". 
+ */
+static BuiltinTypeSpot *graph_export_image_args[] = { 
+	&real_spot,
+	&any_spot 
+};
+
+/* Do a graph_export_image call.
+ */
+static void
+apply_graph_export_image_call( Reduce *rc, 
+	const char *name, HeapNode **arg, PElement *out )
+{
+#ifdef HAVE_LIBGOFFICE
+	PElement rhs;
+	double dpi;
+	Plot *plot;
+	Imageinfo *ii;
+
+	PEPOINTRIGHT( arg[1], &rhs );
+	dpi = PEGETREAL( &rhs );
+
+	PEPOINTRIGHT( arg[0], &rhs );
+	if( !reduce_is_instanceof( rc, CLASS_PLOT, &rhs ) ) {
+		char txt[100];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
+
+		itext_value_ev( rc, &buf, &rhs );
+		error_top( _( "Bad argument." ) );
+		error_sub( _( "Argument 2 to \"%s\" should "
+			"be instance of \"%s\", you passed:\n  %s" ),
+			name, CLASS_PLOT,
+			vips_buf_all( &buf ) );
+		reduce_throw( rc );
+	}
+
+	plot = g_object_new( TYPE_PLOT, NULL );
+
+	if( !classmodel_update_members( CLASSMODEL( plot ), &rhs ) ) {
+		UNREF( plot );
+		reduce_throw( rc );
+	}
+
+	if( !(ii = plot_to_image( plot, rc, dpi )) ) {
+		UNREF( plot );
+		reduce_throw( rc );
+	}
+	UNREF( plot );
+
+	PEPUTP( out, ELEMENT_MANAGED, ii );
+#else /*!HAVE_LIBGOFFICE*/
+	PEPUTP( out, ELEMENT_BOOL, TRUE );
+#endif /*HAVE_LIBGOFFICE*/
+}
+
 /* Args for "math". 
  */
 static BuiltinTypeSpot *math_args[] = { 
@@ -836,21 +896,29 @@ static BuiltinInfo builtin_table[] = {
 	/* Other.
 	 */
 	{ "dir", N_( "return list of names of members" ),
-		FALSE, 1, &dir_args[0], &apply_dir_call },
+		FALSE, IM_NUMBER( dir_args ),
+		&dir_args[0], &apply_dir_call },
 	{ "search", N_( "search for file" ),
-		FALSE, 1, &search_args[0], &apply_search_call },
+		FALSE, IM_NUMBER( search_args ),
+		&search_args[0], &apply_search_call },
 	{ "error", N_( "raise error" ),
-		FALSE, 1, &error_args[0], &apply_error_call },
+		FALSE, IM_NUMBER( error_args ),
+		&error_args[0], &apply_error_call },
 	{ "print", N_( "convert to [char]" ),
-		FALSE, 1, &print_args[0], &apply_print_call },
-	{ "expand", N_( "filexpand environment variables" ),
-		FALSE, 1, &expand_args[0], &apply_expand_call },
+		FALSE, IM_NUMBER( print_args ),
+		&print_args[0], &apply_print_call },
+	{ "expand", N_( "expand environment variables" ),
+		FALSE, IM_NUMBER( expand_args ),
+		&expand_args[0], &apply_expand_call },
 	{ "name2gtype", N_( "convert [char] to GType" ),
-		FALSE, 1, &name2gtype_args[0], &apply_name2gtype_call },
+		FALSE, IM_NUMBER( name2gtype_args ),
+		&name2gtype_args[0], &apply_name2gtype_call },
 	{ "gtype2name", N_( "convert GType to [char]" ),
-		FALSE, 1, &gtype2name_args[0], &apply_gtype2name_call },
+		FALSE, IM_NUMBER( gtype2name_args ),
+		&gtype2name_args[0], &apply_gtype2name_call },
 	{ "_", N_( "look up localised string" ),
-		FALSE, 1, &underscore_args[0], &apply_underscore_call },
+		FALSE, IM_NUMBER( underscore_args ), 
+		&underscore_args[0], &apply_underscore_call },
 
 	/* vips8 wrapper.
 	 */
@@ -959,6 +1027,10 @@ static BuiltinInfo builtin_table[] = {
 	{ "read", N_( "load text file" ),
 		FALSE, IM_NUMBER( read_args ), 
 		&read_args[0], apply_read_call },
+	{ "graph_export_image", N_( "generate image from Plot object" ),
+		FALSE, IM_NUMBER( graph_export_image_args ), 
+		&graph_export_image_args[0], apply_graph_export_image_call },
+
 };
 
 #ifdef HAVE_GSL
