@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -51,14 +51,17 @@ struct _Column {
          */
         int x, y;		/* Position */
         gboolean open;		/* Currently popped down */
-        gboolean open_timeout;	/* Open animate timeout */
-        gboolean open_frames;	/* Frames we've animated */
-        gboolean selected;	/* Currently selected */
+        gboolean selected;
 
 	/* Other state.
 	 */
         int next;		/* Index of next symbol we make */
         Row *last_select;	/* Last row clicked ... for x sel */
+
+	/* A pending scrollto.
+	 */
+	guint scrollto_timeout;
+	ModelScrollPosition pending_position;
 };
 
 typedef struct _ColumnClass {
@@ -77,6 +80,9 @@ GtkType column_get_type( void );
 
 Column *column_new( Workspace *ws, const char *name );
 
+Column *column_get_last_new( void );
+void column_clear_last_new( void );
+
 Row *column_get_bottom( Column *col );
 gboolean column_add_n_names( Column *col, 
 	const char *name, VipsBuf *buf, int nparam );
@@ -87,3 +93,5 @@ void column_set_offset( int x_off, int y_off );
 char *column_name_new( Column *col );
 
 void column_set_open( Column *col, gboolean open );
+
+void column_scrollto( Column *col, ModelScrollPosition position );
