@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -68,6 +68,14 @@ struct _Columnview {
         GtkWidget *textfr;             	/* Enclosing stuff for text entry */
         GtkWidget *capedit;            	/* Shadow text for editing caption */
 
+	/* A shadow for this cview, used during drag to show where this column
+	 * will end up.
+	 *
+	 * And if we are a shadow, the master cview we are the shadow for.
+	 */
+	Columnview *shadow;
+	Columnview *master;
+
         /* Appearance state info.
          */
         int lx, ly;			/* last pos we set */
@@ -76,6 +84,11 @@ struct _Columnview {
         int rx, ry;                     /* Drag offset */
         int tx, ty;                     /* Tally window pos in root cods */
 	gboolean selected;		/* Last drawn in selected state? */
+
+	/* We watch resize events and trigger a workspace relayout with these.
+	 */
+	int old_width;
+	int old_height;
 };
 
 typedef struct _ColumnviewClass {
