@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -445,7 +445,8 @@ filesel_get_mode( const char *filename )
 	return( NULL );
 }
 
-/* Add our image save settings to the end of a filename.
+/* Add our image save settings to the end of a filename. filename must be
+ * at least FILENAME_MAX characters in size.
  */
 void
 filesel_add_mode( char *filename )
@@ -457,7 +458,7 @@ filesel_add_mode( char *filename )
 		int l = strlen( filename );
 
 		mode->mode_fn( ext );
-		im_snprintf( filename + l, MAX_STRSIZE - l, ":%s", ext );
+		im_snprintf( filename + l, FILENAME_MAX - l, ":%s", ext );
 	}
 }
 
@@ -520,10 +521,9 @@ filesel_add_volume( const char *dir, Filesel *filesel )
 {
 	char buf[FILENAME_MAX];
 
-        expand_variables( dir, buf );
-        nativeize_path( buf );
-	absoluteize_path( buf );
-	canonicalize_path( buf );
+	im_strncpy( buf, dir, FILENAME_MAX );
+	path_expand( buf );
+
 	gtk_file_chooser_add_shortcut_folder( 
 		GTK_FILE_CHOOSER( filesel->chooser ), buf, NULL );
 
@@ -713,9 +713,8 @@ filesel_set_filename( Filesel *filesel, const char *name )
 	if( !is_valid_filename( name ) ) 
 		return( FALSE );
 
-        expand_variables( name, buf );
-        nativeize_path( buf );
-	absoluteize_path( buf );
+	im_strncpy( buf, name, FILENAME_MAX );
+	path_expand( buf );
 
 #ifdef DEBUG
 	printf( "filesel_set_filename: %s\n", buf ); 
@@ -748,6 +747,7 @@ char *
 filesel_get_filename( Filesel *filesel )
 {
 	char *name;
+	char tmp[FILENAME_MAX];
 
 	name = gtk_file_chooser_get_filename(
 		GTK_FILE_CHOOSER( filesel->chooser ) );
@@ -766,7 +766,13 @@ filesel_get_filename( Filesel *filesel )
 		return( NULL );
 	}
 
-	return( name );
+	/* Rewrite to compact form, eg. "$HOME/fred".
+	 */
+	im_strncpy( tmp, name, FILENAME_MAX );
+	path_compact( tmp );
+	g_free( name );
+
+	return( g_strdup( tmp ) );
 }
 
 /* Get filename multi ... map over the selected filenames.
@@ -781,9 +787,14 @@ filesel_map_filename_multi( Filesel *filesel,
 
 	for( p = names; p; p = p->next ) {
 		char *filename = (char *) p->data;
+
+		char tmp[FILENAME_MAX];
 		void *res;
 
-		if( (res = fn( filesel, filename, a, b )) ) {
+		im_strncpy( tmp, filename, FILENAME_MAX );
+		path_compact( tmp );
+
+		if( (res = fn( filesel, tmp, a, b )) ) {
 			IM_FREEF( slist_free_all, names );
 			return( res );
 		}
@@ -1041,11 +1052,12 @@ filesel_refresh( Filesel *filesel )
 {
 	char *dir;
 
-	dir = gtk_file_chooser_get_current_folder( 
-		GTK_FILE_CHOOSER( filesel->chooser ) );
-	gtk_file_chooser_set_current_folder(
-		GTK_FILE_CHOOSER( filesel->chooser ), dir );
-	g_free( dir );
+	if( (dir = gtk_file_chooser_get_current_folder( 
+		GTK_FILE_CHOOSER( filesel->chooser ) )) ) { 
+		gtk_file_chooser_set_current_folder(
+			GTK_FILE_CHOOSER( filesel->chooser ), dir );
+		g_free( dir );
+	}
 
         return( NULL );
 }
