@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -35,15 +35,31 @@
 
 static ViewClass *parent_class = NULL;
 
+static iRegiongroup *
+iregiongroupview_get_iregiongroup( iRegiongroupview *iregiongroupview )
+{
+	return( IREGIONGROUP( VOBJECT( iregiongroupview )->iobject ) ); 
+}
+
+static Classmodel *
+iregiongroupview_get_classmodel( iRegiongroupview *iregiongroupview )
+{
+	iRegiongroup *iregiongroup;
+
+	if( (iregiongroup = 
+		iregiongroupview_get_iregiongroup( iregiongroupview )) )
+		return( CLASSMODEL( ICONTAINER( iregiongroup )->parent ) );
+
+	return( NULL );
+}
+
 static void
 iregiongroupview_destroy( GtkObject *object )
 {
 	iRegiongroupview *iregiongroupview;
-	iObject *iobject;
-	iContainer *parent;
 
 #ifdef DEBUG
-	printf( "iregiongroupview_destroy\n" );
+	printf( "iregiongroupview_destroy: %p\n", object );
 #endif /*DEBUG*/
 
 	g_return_if_fail( object != NULL );
@@ -53,10 +69,8 @@ iregiongroupview_destroy( GtkObject *object )
 
 	/* Destroy all regionviews we manage.
 	 */
-	if( (iobject = VOBJECT( iregiongroupview )->iobject) &&
-		(parent = ICONTAINER( iobject )->parent) ) 
-		slist_map( CLASSMODEL( parent )->views, 
-			(SListMapFn) object_destroy, NULL );
+	slist_map( iregiongroupview->classmodel->views, 
+		(SListMapFn) object_destroy, NULL );
 
 	GTK_OBJECT_CLASS( parent_class )->destroy( object );
 }
@@ -138,29 +152,36 @@ static void
 iregiongroupview_refresh( vObject *vobject )
 {
 	iRegiongroupview *iregiongroupview = IREGIONGROUPVIEW( vobject );
-	Classmodel *classmodel = CLASSMODEL( vobject->iobject );
 
 	iRegiongroupviewRefreshState irs;
 
 #ifdef DEBUG
 	printf( "iregiongroupview_refresh\n" );
+	printf( "watching model %s %s\n", 
+		G_OBJECT_TYPE_NAME( vobject->iobject ), 
+		NN( IOBJECT( vobject->iobject )->name ) );
 #endif /*DEBUG*/
 
-	/* Make a note of all the displays we have now, loop over the 
-	 * displays we should have, reusing when possible ... remove any 
-	 * unused displays at the end.
-	 */
-	irs.classmodel = CLASSMODEL( ICONTAINER( classmodel )->parent );
-	irs.notused = g_slist_copy( irs.classmodel->views );
-	irs.iregiongroupview = iregiongroupview;
+	iregiongroupview->classmodel = 
+		iregiongroupview_get_classmodel( iregiongroupview );
 
-	slist_map( irs.classmodel->iimages,
-		(SListMapFn) iregiongroupview_refresh_iimage, &irs );
+	if( iregiongroupview->classmodel ) { 
+		/* Make a note of all the displays we have now, loop over the 
+		 * displays we should have, reusing when possible ... remove 
+		 * any unused displays at the end.
+		 */
+		irs.classmodel = iregiongroupview->classmodel;
+		irs.notused = g_slist_copy( irs.classmodel->views );
+		irs.iregiongroupview = iregiongroupview;
 
-	/* Remove all the regionviews we've not used. 
-	 */
-	slist_map( irs.notused, (SListMapFn) object_destroy, NULL );
-	IM_FREEF( g_slist_free, irs.notused );
+		slist_map( irs.classmodel->iimages,
+			(SListMapFn) iregiongroupview_refresh_iimage, &irs );
+
+		/* Remove all the regionviews we've not used. 
+		 */
+		slist_map( irs.notused, (SListMapFn) object_destroy, NULL );
+		IM_FREEF( g_slist_free, irs.notused );
+	}
 
 	VOBJECT_CLASS( parent_class )->refresh( vobject );
 }
