@@ -22,6 +22,14 @@ extern void nip_VOID__DOUBLE_DOUBLE (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
+/* BOOLEAN:INT,INT (nipmarshal.list:27) */
+extern void nip_BOOLEAN__INT_INT (GClosure     *closure,
+                                  GValue       *return_value,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint,
+                                  gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __nip_MARSHAL_H__ */
