@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -55,7 +55,13 @@ extern InputState input_state;
 void nip2yyerror( const char *sub, ... )
 	__attribute__((format(printf, 1, 2)));
 void yyerror( const char *msg ); 
+#ifdef YYLENG_IS_YY_SIZE_T
+/* Assume yy_size_t is size_t.
+ */
+extern size_t yyleng;
+#else
 extern int yyleng;			/* lex stuff */
+#endif
 
 /* Lex gathers tokens here for workspace.c
  */
