@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -35,11 +35,11 @@
 #define DEBUG_SEARCH
  */
 
-#include "ip.h"
-
-/* List of directories we have visited this session. Added to by fsb stuff.
+/* show path rewrites
+#define DEBUG_REWRITE
  */
-GSList *path_session = NULL;
+
+#include "ip.h"
 
 /* Default search paths if prefs fail.
  */
@@ -47,6 +47,255 @@ GSList *path_start_default = NULL;
 GSList *path_search_default = NULL;
 const char *path_tmp_default = NULL;
 
+/* We rewrite paths to try to handle files referenced in workspaces in 
+ * directories that move.
+ *
+ * For example, suppose we have workspace.ws in /some/directory which loads
+ * image.v in that directory. The workspace will include a line like 
+ * (Image_file "/some/directory/image"). Now if directory is moved to
+ * /other/directory and workspace.ws reloaded, we want to rewrite the string
+ * "/some/directory/image.v" to "/other/directory/image.v". 
+ *
+ * Also consider picking ICC profiles in export/import: we want to avoid
+ * putting the path into the ws file, we need to go back to "$VIPSHOME" again.
+ *
+ * Rewrite rules can be "locked". For example, we don't want the rewrite from
+ * "/home/john" to "$HOME" to ever be removed. 
+ */
+
+typedef struct _Rewrite {
+	char *old;
+	char *new;
+	gboolean lock;
+} Rewrite; 
+
+static GSList *rewrite_list = NULL;
+
+static void
+path_rewrite_free( Rewrite *rewrite )
+{
+	rewrite_list = g_slist_remove( rewrite_list, rewrite );
+
+	IM_FREE( rewrite->old ); 
+	IM_FREE( rewrite->new ); 
+	IM_FREE( rewrite ); 
+}
+
+void
+path_rewrite_free_all( void )
+{
+	while( rewrite_list ) { 
+		Rewrite *rewrite = (Rewrite *) rewrite_list->data; 
+
+		IM_FREEF( path_rewrite_free, rewrite );
+	}
+}
+
+static Rewrite *
+path_rewrite_new( const char *old, const char *new, gboolean lock )
+{
+	Rewrite *rewrite;
+
+	rewrite = g_new( Rewrite, 1 );
+	rewrite->old = g_strdup( old );
+	rewrite->new = g_strdup( new );
+	rewrite->lock = lock;
+	rewrite_list = g_slist_prepend( rewrite_list, rewrite );
+
+	return( rewrite ); 
+}
+
+static gint
+path_rewrite_sort_fn( Rewrite *a, Rewrite *b )
+{
+        return( strlen( b->old ) - strlen( a->old ) );
+}
+
+static Rewrite *
+path_rewrite_lookup( const char *old )
+{
+	GSList *p;
+	Rewrite *rewrite;
+
+	for( p = rewrite_list; p; p = p->next ) {
+		rewrite = (Rewrite *) p->data; 
+
+		if( strcmp( old, rewrite->old ) == 0 ) 
+			return( rewrite );
+	}
+
+	return( NULL );
+}
+
+/* Add a new rewrite pair to the rewrite list. @new can be NULL, meaning
+ * remove a rewrite rule.
+ */
+void
+path_rewrite_add( const char *old, const char *new, gboolean lock )
+{
+	char old_buf[FILENAME_MAX + 1];
+	char new_buf[FILENAME_MAX + 1];
+
+	Rewrite *rewrite;
+
+#ifdef DEBUG_REWRITE
+	printf( "path_rewrite_add: old = %s, new = %s, lock = %d\n", 
+		old, new, lock );
+#endif /*DEBUG_REWRITE*/
+
+	g_return_if_fail( old );
+
+	/* We want the old path in long form, with a trailing '/'. The
+	 * trailing '/' will stop us rewriting filenames.
+	 *
+	 * If we keep all @old paths in long form we can avoid rewrite loops.
+	 */
+	im_strncpy( old_buf, old, FILENAME_MAX );
+	strcat( old_buf, G_DIR_SEPARATOR_S );
+	path_expand( old_buf );
+	old = old_buf;
+
+	if( new ) {
+		/* We must keep the new path in short (unexpanded) form, 
+		 * obviously.
+		 */
+		im_strncpy( new_buf, new, FILENAME_MAX );
+		strcat( new_buf, G_DIR_SEPARATOR_S );
+		new = new_buf;
+	}
+
+	/* If old is a prefix of new we will get endless expansion.
+	 */
+	if( new &&
+		is_prefix( old, new ) )
+		return; 
+
+	if( (rewrite = path_rewrite_lookup( old )) ) {
+		if( !rewrite->lock &&
+			(!new ||
+			 strcmp( old, new ) == 0) ) {
+#ifdef DEBUG_REWRITE
+			printf( "path_rewrite_add: removing\n" );
+#endif /*DEBUG_REWRITE*/
+
+			IM_FREEF( path_rewrite_free, rewrite );
+		}
+		else if( !rewrite->lock &&
+			new ) {
+#ifdef DEBUG_REWRITE
+			printf( "path_rewrite_add: updating\n" );
+#endif /*DEBUG_REWRITE*/
+
+			IM_SETSTR( rewrite->new, new );
+		}
+		else {
+#ifdef DEBUG_REWRITE
+			printf( "path_rewrite_add: rewrite rule locked\n" );
+#endif /*DEBUG_REWRITE*/
+		}
+	}
+	else if( new &&
+		strcmp( old, new ) != 0 ) {
+#ifdef DEBUG_REWRITE
+		printf( "path_rewrite_add: adding\n" );
+#endif /*DEBUG_REWRITE*/
+
+		(void) path_rewrite_new( old, new, lock );
+	}
+
+	/* Keep longest old first, in case one old is a prefix of 
+	 * another.
+	 */
+	rewrite_list = g_slist_sort( rewrite_list, 
+		(GCompareFunc) path_rewrite_sort_fn );
+
+#ifdef DEBUG_REWRITE
+{
+	GSList *p;
+
+	printf( "path_rewrite_add: state:\n" );
+
+	for( p = rewrite_list; p; p = p->next ) {
+		rewrite = (Rewrite *) p->data; 
+
+		printf( "\told = %s, new = %s\n", rewrite->old, rewrite->new );
+	}
+}
+#endif /*DEBUG_REWRITE*/
+}
+
+/* Rewrite a string using the rewrite list. buf must be FILENAME_MAX
+ * characters.
+ */
+void
+path_rewrite( char *buf )
+{
+	GSList *p;
+	gboolean changed;
+
+#ifdef DEBUG_REWRITE
+	printf( "path_rewrite: %s\n", buf );
+#endif /*DEBUG_REWRITE*/
+
+	do { 
+		changed = FALSE;
+
+		for( p = rewrite_list; p; p = p->next ) {
+			Rewrite *rewrite = (Rewrite *) p->data; 
+
+			if( is_prefix( rewrite->old, buf ) ) {
+				int olen = strlen( rewrite->old );
+				int nlen = strlen( rewrite->new );
+				int blen = strlen( buf );
+
+				if( blen - olen + nlen > FILENAME_MAX - 3 )
+					break;
+
+				memmove( buf + nlen, buf + olen, 
+					blen - olen + 1 );
+				memcpy( buf, rewrite->new, nlen );
+
+				changed = TRUE;
+
+				break;
+			}
+		}
+	} while( changed );
+
+#ifdef DEBUG_REWRITE
+	printf( "\t-> %s\n", buf );
+#endif /*DEBUG_REWRITE*/
+}
+
+/* The inverse: rewrite in long form ready for file ops.
+ */
+void
+path_expand( char *path )
+{
+	char buf[FILENAME_MAX];
+
+	expand_variables( path, buf );
+	nativeize_path( buf );
+	absoluteize_path( buf );
+	canonicalize_path( buf );
+	im_strncpy( path, buf, FILENAME_MAX );
+}
+
+/* Rewite a path to compact form. @path must be FILENAME_MAX characters.
+ *
+ * Examples:
+ *
+ * 	/home/john/../somefile 		-> $HOME/../somefile
+ * 	/home/./john/../somefile 	-> $HOME/../somefile
+ * 	fred				-> ./fred
+ */
+void
+path_compact( char *path )
+{
+	path_expand( path );
+	path_rewrite( path );
+}
+
 /* Turn a search path (eg. "/pics/lr:/pics/hr") into a list of directory names.
  */
 GSList *
@@ -213,6 +462,9 @@ path_search_match( Search *search, const char *dir_name, const char *name )
 
 		im_snprintf( buf, FILENAME_MAX, 
 			"%s" G_DIR_SEPARATOR_S "%s", dir_name, name );
+
+		path_compact( buf );
+
 #ifdef DEBUG_SEARCH
 		printf( "path_search_match: matched \"%s\"\n", buf );
 #endif /*DEBUG_SEARCH*/
@@ -267,28 +519,6 @@ path_scan_dir( const char *dir_name, Search *search )
 
  */
 void *
-path_map_exact( GSList *path, const char *patt, path_map_fn fn, void *a )
-{
-	Search search;
-	void *result;
-
-#ifdef DEBUG_SEARCH
-	printf( "path_map_exact: searching for \"%s\"\n", patt );
-#endif /*DEBUG_SEARCH*/
-
-	if( !path_search_init( &search, patt, fn, a ) )
-		return( NULL );
-
-	result = slist_map( path, (SListMapFn) path_scan_dir, &search );
-
-	path_search_free( &search );
-
-	return( result );
-}
-
-/* As above, but walk the session path too.
- */
-void *
 path_map( GSList *path, const char *patt, path_map_fn fn, void *a )
 {
 	Search search;
@@ -302,9 +532,6 @@ path_map( GSList *path, const char *patt, path_map_fn fn, void *a )
 		return( NULL );
 
 	result = slist_map( path, (SListMapFn) path_scan_dir, &search );
-	if( !result )
-		result = slist_map( path_session, 
-			(SListMapFn) path_scan_dir, &search );
 
 	path_search_free( &search );
 
@@ -338,14 +565,17 @@ path_map_dir( const char *dir, const char *patt, path_map_fn fn, void *a )
 	return( result );
 }
 
-/* Search for a file and return it's path. NULL for not found. Return a new
- * string.
+/* Search for a file on the search path. 
  */
 char *
-path_find_file( GSList *path, const char *filename )
+path_find_file( const char *filename )
 {
 	char *fname;
 
+#ifdef DEBUG_SEARCH
+	printf( "path_find_file: \"%s\"\n", filename );
+#endif /*DEBUG_SEARCH*/
+
 	/* Try file name exactly.
 	 */
 	if( existsf( "%s", filename ) )
@@ -353,7 +583,7 @@ path_find_file( GSList *path, const char *filename )
 
 	/* Search everywhere.
 	 */
-	if( (fname = path_map( path, filename,
+	if( (fname = path_map( PATH_SEARCH, filename,
 		(path_map_fn) im_strdupn, NULL )) )
 		return( fname );
 	
@@ -363,45 +593,31 @@ path_find_file( GSList *path, const char *filename )
 	return( NULL );
 }
 
-/* Add a directory to the session path, if it's not there already.
- */
-void
-path_add_dir( const char *dir )
-{
-        if( !slist_map( path_session, 
-		(SListMapFn) path_str_eq, (gpointer) dir ) ) {
-#ifdef DEBUG_SEARCH
-		printf( "path_add_dir: adding \"%s\"\n", dir );
-#endif /*DEBUG_SEARCH*/
-                path_session = g_slist_prepend( path_session, 
-			im_strdup( NULL, dir ) );
-	}
-}
-
-void
-path_add_file( const char *filename )
-{
-	char *p;
-	char buf[FILENAME_MAX];
-
-	im_strncpy( buf, filename, FILENAME_MAX );
-	if( (p = strrchr( buf, G_DIR_SEPARATOR )) )
-		*p = '\0';
-
-	path_add_dir( buf );
-}
-
 void
 path_init( void )
 {
+	char buf[FILENAME_MAX];
+
+	path_rewrite_add( get_prefix(), "$VIPSHOME", TRUE );
+	path_rewrite_add( g_get_home_dir(), "$HOME", TRUE );
+	path_rewrite_add( get_savedir(), "$SAVEDIR", TRUE );
+
+	/* You might think we could add a rule to swap '.' for 
+	 * g_get_current_dir(), but that would then make workspaces depend on
+	 * a certain value of cwd before they could work.
+	 */
+
+	/* And the expanded form too.
+	 */
+	expand_variables( get_savedir(), buf );
+	path_rewrite_add( buf, "$SAVEDIR", TRUE );
+
 #ifdef DEBUG_LOCAL
 	printf( "path_init: loading start from \".\" only\n" );
 	path_start_default = path_parse( "." );
 	path_search_default = path_parse( "." );
 	path_tmp_default = im_strdup( NULL, "." );
 #else /*!DEBUG_LOCAL*/
-	char buf[FILENAME_MAX];
-
 	im_snprintf( buf, FILENAME_MAX,
 		"%s" G_DIR_SEPARATOR_S "start" G_SEARCHPATH_SEPARATOR_S
 		"$VIPSHOME" G_DIR_SEPARATOR_S "share" G_DIR_SEPARATOR_S
