@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -125,12 +125,14 @@ is_member_enclosing( Compile *compile, Symbol *sym )
 gboolean
 is_scope( Symbol *sym )
 {
-	return( sym->type == SYM_ROOT || sym->type == SYM_WORKSPACE || 
-		sym->type == SYM_WORKSPACEGROUP || !symbol_get_parent( sym ) );
+	return( sym->type == SYM_ROOT || 
+		sym->type == SYM_WORKSPACE || 
+		sym->type == SYM_WORKSPACEROOT || 
+		!symbol_get_parent( sym ) );
 }
 
 /* Is a symbol a top-level definition. Tops are symbols whose parents are 
- * all SYM_ROOT, SYM_WORKSPACE or SYM_WORKSPACEGROUP.
+ * SYM_ROOT, SYM_WORKSPACE and friends.
  */
 gboolean
 is_top( Symbol *sym )
