@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -45,7 +45,8 @@ prefs_destroy( GtkObject *object )
 #endif /*DEBUG*/
 
 	if( prefs->ws ) {
-		Filemodel *filemodel = FILEMODEL( prefs->ws );
+		Workspacegroup *wsg = workspace_get_workspacegroup( prefs->ws );
+		Filemodel *filemodel = FILEMODEL( wsg );
 
 		/* Force a recalc, in case we've changed the autorecalc 
 		 * settings. Also does a scan on any widgets.
@@ -53,7 +54,7 @@ prefs_destroy( GtkObject *object )
 		symbol_recalculate_all_force( TRUE );
 
 		if( filemodel->modified &&
-			filemodel_save_all( filemodel, filemodel->filename ) ) 
+			filemodel_top_save( filemodel, filemodel->filename ) ) 
 			filemodel_set_modified( filemodel, FALSE );
 	}
 
@@ -196,9 +197,9 @@ prefs_column_compare( Column *a, Column *b )
 Prefs *
 prefs_new( const char *caption_filter )
 {
-	Symbol *wsg_sym = main_workspacegroup->sym;
+	Symbol *wsr_sym = main_workspaceroot->sym;
 	Symbol *ws_sym = SYMBOL( icontainer_child_lookup( 
-		ICONTAINER( wsg_sym->expr->compile ), "Preferences" ) );
+		ICONTAINER( wsr_sym->expr->compile ), "Preferences" ) );
 	Prefs *prefs;
 
 	if( !ws_sym ) {
@@ -226,7 +227,8 @@ prefs_set( const char *name, const char *fmt, ... )
 {
 	Watch *watch;
 
-	if( (watch = watch_find( main_watchgroup, name )) ) {
+	if( main_watchgroup &&
+		(watch = watch_find( main_watchgroup, name )) ) {
 		va_list args;
 
 		va_start( args, fmt );
