@@ -16,9 +16,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -45,7 +45,7 @@ rhsview_reset( View *view )
 	Rhs *rhs = RHS( VOBJECT( rhsview )->iobject );
 	Row *row = HEAPMODEL( rhs )->row;
 
-	model_set_display( rhs->itext, 
+	model_display( rhs->itext, 
 		row->ws->mode == WORKSPACE_MODE_FORMULA || 
 		rhs->flags & RHS_ITEXT );
 
@@ -74,16 +74,16 @@ rhsview_refresh( vObject *vobject )
 
 	/* Add/remove children according to rhs->flags. 
 	 */
-	model_set_display( rhs->graphic, rhs->flags & RHS_GRAPHIC );
-	model_set_display( rhs->scol, rhs->flags & RHS_SCOL );
+	model_display( rhs->graphic, rhs->flags & RHS_GRAPHIC );
+	model_display( rhs->scol, rhs->flags & RHS_SCOL );
 
 	switch( row->ws->mode ) {
 	case WORKSPACE_MODE_REGULAR:
-		model_set_display( rhs->itext, rhs->flags & RHS_ITEXT );
+		model_display( rhs->itext, rhs->flags & RHS_ITEXT );
 		break;
 
 	case WORKSPACE_MODE_FORMULA:
-		model_set_display( rhs->itext, TRUE );
+		model_display( rhs->itext, TRUE );
 		break;
 
 	case WORKSPACE_MODE_NOEDIT:
@@ -92,12 +92,12 @@ rhsview_refresh( vObject *vobject )
 		 */
 		if( rhs->graphic &&
 			rhs->flags & RHS_GRAPHIC )
-			model_set_display( rhs->itext, FALSE );
+			model_display( rhs->itext, FALSE );
 		else if( rhs->scol &&
 			rhs->flags & RHS_SCOL )
-			model_set_display( rhs->itext, FALSE );
+			model_display( rhs->itext, FALSE );
 		else
-			model_set_display( rhs->itext, 
+			model_display( rhs->itext, 
 				rhs->flags & RHS_ITEXT );
 		break;
 
