@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -300,7 +300,7 @@ symbol_clear( Symbol *sym )
 
 	sym->builtin = NULL;
 
-	sym->wsg = NULL;
+	sym->wsr = NULL;
 
 	sym->ws = NULL;
 }
@@ -415,11 +415,11 @@ symbol_strip( Symbol *sym )
 	 */
 	IM_FREEF( g_slist_free, sym->patch );
 
-	/* Workspacegroup? Unlink from wsg.
+	/* Workspaceroot? Unlink from wsr.
 	 */
-	if( sym->wsg ) {
-		sym->wsg->sym = NULL;
-		sym->wsg = NULL;
+	if( sym->wsr ) {
+		sym->wsr->sym = NULL;
+		sym->wsr = NULL;
 	}
 
 	/* Workspace? Unlink from ws.
@@ -711,6 +711,41 @@ symbol_new( Compile *compile, const char *name )
 	return( sym );
 }
 
+gboolean
+symbol_rename( Symbol *sym, const char *new_name )
+{
+	Compile *compile = COMPILE( ICONTAINER( sym )->parent );
+	Symbol *old_sym;
+
+	if( strcmp( IOBJECT( sym )->name, new_name ) == 0 )
+		return( TRUE );
+	
+	if( (old_sym = compile_lookup( compile, new_name )) ) {
+		error_top( "%s", _( "Name in use." ) );
+		error_sub( _( "Can't rename %s \"%s\" as \"%s\". "
+			"The name is already in use." ), 
+			decode_SymbolType_user( sym->type ), 
+			IOBJECT( sym )->name,
+			new_name );
+		return( FALSE );
+	}
+
+	/* Everything that depends on us will break.
+	 */
+	symbol_dirty_intrans( sym, link_serial_new() );
+
+	g_object_ref( sym );
+
+	icontainer_child_remove( ICONTAINER( sym ) );
+	iobject_set( IOBJECT( sym ), new_name, NULL );
+	icontainer_child_add( ICONTAINER( compile ), ICONTAINER( sym ),
+		ICONTAINER( sym )->pos );
+
+	g_object_unref( sym );
+
+	return( TRUE );
+}
+
 void
 symbol_error_redefine( Symbol *sym )
 {
@@ -958,7 +993,12 @@ symbol_recalculate_sub( Symbol *sym )
 		 * mechanism. 
 		 */
 		row_recomp( sym->expr->row );
-		if( sym->expr->row->err )
+
+		/* Stuff may have been removed.
+		 */
+		if( sym->expr &&
+			sym->expr->row &&
+			sym->expr->row->err )
 			result = FALSE;
 	}
 	else if( sym->expr->compile->nparam == 0 ) {
@@ -977,6 +1017,29 @@ symbol_recalculate_sub( Symbol *sym )
 	return( result );
 }
 
+/* Note the name of the last thing we calced here, for progress to display.
+ */
+static char symbol_last_calc_txt[256];
+static VipsBuf symbol_last_calc_buf = VIPS_BUF_STATIC( symbol_last_calc_txt );
+
+static void
+symbol_note_calc_name( Symbol *sym )
+{
+	Symbol *scope = symbol_get_scope( sym );
+	VipsBuf *buf = &symbol_last_calc_buf;
+
+	vips_buf_rewind( buf );
+	vips_buf_appends( buf, NN( IOBJECT( scope )->name ) );
+	vips_buf_appends( buf, "." );
+	symbol_qualified_name_relative( scope, sym, buf );
+}
+
+const char *
+symbol_get_last_calc( void )
+{
+	return( vips_buf_all( &symbol_last_calc_buf ) ); 
+}
+
 /* We can get called recursively .. eg. we do an im_tiff2vips(), that
  * pops a progress box, that triggers idle, that tries to recalc a
  * leaf again.
@@ -985,13 +1048,13 @@ static gboolean symbol_running = FALSE;
 
 /* Recalc a symbol ... with error checks.
  */
-void *
-symbol_recalculate_check( Symbol *sym )
+static void *
+symbol_recalculate_leaf_sub( Symbol *sym )
 {
 #ifdef DEBUG_RECALC
-	printf( "symbol_recalculate_check: %s\n", symbol_name_scope( sym ) );
+	printf( "symbol_recalculate_leaf_sub: %s\n", symbol_name_scope( sym ) );
 
-	/* We can symbol_recalculate_check() syms which are not dirty.
+	/* We can symbol_recalculate_leaf_sub() syms which are not dirty.
 	 */
 	g_assert( !sym->dirty || symbol_is_leafable( sym ) );
 
@@ -1020,6 +1083,7 @@ symbol_recalculate_check( Symbol *sym )
 	reduce_context->heap->filled = FALSE;
 	symbol_running = TRUE;
 	progress_begin();
+	symbol_note_calc_name( sym );
 	if( !symbol_recalculate_sub( sym ) || 
 		reduce_context->heap->filled ) {
 		expr_error_set( sym->expr );
@@ -1041,12 +1105,14 @@ symbol_recalculate_check( Symbol *sym )
 	 */
 	if( !sym->ndirtychildren ) {
 		symbol_dirty_clear( sym );
-		expr_new_value( sym->expr );
+		if( sym->expr ) {
+			expr_new_value( sym->expr );
 
 #ifdef DEBUG_RECALC
-		printf( "\tsuccess: " ); 
-		graph_pointer( &sym->expr->root );
+			printf( "\tsuccess: " ); 
+			graph_pointer( &sym->expr->root );
 #endif /*DEBUG_RECALC*/
+		}
 	}
 #ifdef DEBUG_RECALC
 	else {
@@ -1086,7 +1152,7 @@ symbol_recalculate_leaf( void )
 
 		/* Found a symbol!
 		 */
-		(void) symbol_recalculate_check( sym );
+		(void) symbol_recalculate_leaf_sub( sym );
 
 		/* Note a pending GC.
 		 */
@@ -1107,20 +1173,45 @@ static gint symbol_idle_id = 0;
 static gboolean
 symbol_recalculate_idle_cb( void )
 {
+	static GTimer *timer = NULL;
+
 	gboolean run_again;
 
+#ifdef DEBUG_RECALC
+	printf( "symbol_recalculate_idle_cb:\n" ); 
+#endif /*DEBUG_RECALC*/
+
+	if( symbol_running ) 
+		/* We've been run from a nested main loop, perhaps from the
+		 * progress bar. Just run again and perhaps next time we'll be
+		 * back in the top-level main loop.
+		 */
+		return( TRUE ); 
+
+	if( !timer )
+		timer = g_timer_new();
+
+	g_timer_reset( timer );
+
 	run_again = TRUE;
 
-	if( !symbol_running ) {
-		progress_begin();
+	if( !mainw_auto_recalc ) 
+		/* Auto-calc has been turned off during a recomp.
+		 */
+		run_again = FALSE; 
+	else
+		while( g_timer_elapsed( timer, NULL ) < 0.1 )
+			if( !symbol_recalculate_leaf() ) {
+				run_again = FALSE;
+				break;
+			}
 
-		if( !symbol_recalculate_leaf() ) {
-			/* Nothing more to do: shut down idle recomp.
-			 */
-			symbol_idle_id = 0;
-			run_again = FALSE;
-		}
+	if( !run_again ) {
+#ifdef DEBUG_RECALC
+		printf( "symbol_recalculate_idle_cb: bg recalc done\n" ); 
+#endif /*DEBUG_RECALC*/
 
+		symbol_idle_id = 0;
 		progress_end();
 	}
 
@@ -1146,7 +1237,8 @@ symbol_recalculate_all_force( gboolean now )
 		/* Do nothing.
 		 */
 		;
-	else if( main_option_batch || now ) {
+	else if( main_option_batch || 
+		now ) {
 		progress_begin();
 
 		while( symbol_recalculate_leaf() )
@@ -1154,9 +1246,16 @@ symbol_recalculate_all_force( gboolean now )
 
 		progress_end();
 	}
-	else if( !symbol_idle_id ) 
+	else if( !symbol_idle_id ) {
+#ifdef DEBUG_RECALC
+		printf( "symbol_recalculate_all_force: "
+			"starting bg recalc ...\n" ); 
+#endif /*DEBUG_RECALC*/
+
+		progress_begin();
 		symbol_idle_id = g_idle_add( 
 			(GSourceFunc) symbol_recalculate_idle_cb, NULL );
+	}
 }
 
 /* Recalculate the symbol table.
@@ -1172,3 +1271,15 @@ symbol_recalculate_all( void )
 	if( mainw_auto_recalc )
 		symbol_recalculate_all_force( FALSE );
 }
+
+/* Recalc a symbol ... with error checks.
+ */
+gboolean
+symbol_recalculate_check( Symbol *sym )
+{
+	gboolean result;
+
+	result = symbol_recalculate_leaf_sub( sym ) == NULL;
+
+	return( result );
+}
