@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -42,28 +42,6 @@ toolkit_map( Toolkit *kit, tool_map_fn fn, void *a, void *b )
 		(icontainer_map_fn) fn, a, b ) );
 }
 
-static void 
-toolkit_dispose( GObject *gobject )
-{
-	Toolkit *kit;
-
-	g_return_if_fail( gobject != NULL );
-	g_return_if_fail( IS_TOOLKIT( gobject ) );
-
-	kit = TOOLKIT( gobject );
-
-#ifdef DEBUG
-	printf( "toolkit_dispose %s\n", IOBJECT( kit )->name );
-#endif /*DEBUG*/
-
-	/* Kill all the symbols we contain.
-	 */
-	icontainer_map( ICONTAINER( kit ),
-		(icontainer_map_fn) icontainer_child_remove, NULL, NULL );
-
-	G_OBJECT_CLASS( parent_class )->dispose( gobject );
-}
-
 static void
 toolkit_changed( iObject *iobject )
 {
@@ -132,7 +110,6 @@ toolkit_load_text( Model *model, Model *parent, iOpenFile *of )
 static void
 toolkit_class_init( ToolkitClass *class )
 {
-	GObjectClass *gobject_class = (GObjectClass *) class;
 	iObjectClass *iobject_class = (iObjectClass *) class;
 	ModelClass *model_class = (ModelClass *) class;
 	FilemodelClass *filemodel_class = (FilemodelClass *) class;
@@ -144,8 +121,6 @@ toolkit_class_init( ToolkitClass *class )
 
 	/* Init methods.
 	 */
-	gobject_class->dispose = toolkit_dispose;
-
 	iobject_class->info = toolkit_info;
 	iobject_class->changed = toolkit_changed;
 
@@ -252,7 +227,8 @@ toolkit_new_from_file( Toolkitgroup *kitg, const char *filename )
 	Toolkit *kit = toolkit_new_filename( kitg, filename );
 	gboolean res;
 
-	res = filemodel_load_all( FILEMODEL( kit ), MODEL( kitg ), filename );
+	res = filemodel_load_all( FILEMODEL( kit ), MODEL( kitg ), 
+		filename, NULL );
 	filemodel_set_modified( FILEMODEL( kit ), FALSE );
 
 	/* Don't remove the kit if load failed, we want to leave it so the 
