@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -55,9 +55,12 @@ struct _View {
 	guint pos_changed_sid;		/* Signals we use to watch iObject */
 	guint scrollto_sid;
 	guint layout_sid;
+	guint front_sid;
 	guint reset_sid;
 	guint child_add_sid;
 	guint child_remove_sid;
+	guint child_detach_sid;
+	guint child_attach_sid;
 
 	View *parent;			/* Enclosing view (if any) */
 	GSList *managed;		/* List of ViewChild for us */
