@@ -16,9 +16,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -42,7 +42,7 @@ static GtkVBoxClass *parent_class = NULL;
 
 static Queue *vobject_dirty = NULL;
 
-static gint vobject_idle_running = 0;
+static gint vobject_refresh_timeout = 0;
 
 /* Remove from refresh queue.
  */
@@ -63,8 +63,8 @@ vobject_refresh_dequeue( vObject *vobject )
 #ifdef DEBUG_TIME
 /* Refresh all vobjects at once and time them.
  */
-static gint
-vobject_idle_refresh( gpointer user_data )
+static gboolean
+vobject_refresh_timeout_cb( gpointer user_data )
 {
 	static GTimer *refresh_timer = NULL;
 	double last_elapsed;
@@ -73,6 +73,8 @@ vobject_idle_refresh( gpointer user_data )
 	void *data;
 	int n;
 
+	vobject_refresh_timeout = 0;
+
 	if( !refresh_timer )
 		refresh_timer = g_timer_new();
 
@@ -102,23 +104,27 @@ vobject_idle_refresh( gpointer user_data )
 	printf( "vobject_idle_refresh: worst %gs (refresh %d)\n", 
 		worst_time, worst_index );
 
-	vobject_idle_running = 0;
-
 	return( FALSE );
 }
 #else /*DEBUG_TIME*/
-/* Refresh stuff off the dirty list. Runs as an idle task.
+/* Refresh stuff off the dirty list. 
  */
-static gint
-vobject_idle_refresh( gpointer user_data )
+static gboolean
+vobject_refresh_timeout_cb( gpointer user_data )
 {
 	void *data;
 
+#ifdef DEBUG
+	printf( "vobject_refresh_timeout_cb:\n" ); 
+#endif /*DEBUG*/
+
+	vobject_refresh_timeout = 0;
+
 	while( (data = queue_head( vobject_dirty ) ) ) {
 		vObject *vobject = VOBJECT( data );
 
 #ifdef DEBUG
-		printf( "vobject_idle_refresh: starting \"%s\" (%p)\n", 
+		printf( "vobject_refresh_timeout_cb: starting \"%s\" (%p)\n", 
 			G_OBJECT_TYPE_NAME( vobject ), vobject );
 #endif /*DEBUG*/
 
@@ -130,8 +136,6 @@ vobject_idle_refresh( gpointer user_data )
 		vobject_refresh( vobject );
 	}
 
-	vobject_idle_running = 0;
-
 	return( FALSE );
 }
 #endif /*DEBUG_TIME*/
@@ -156,9 +160,9 @@ vobject_refresh_queue( vObject *vobject )
 		vobject->dirty = TRUE;
 		queue_add( vobject_dirty, vobject );
 
-		if( !vobject_idle_running )
-			vobject_idle_running = 
-				gtk_idle_add( vobject_idle_refresh, NULL );
+		IM_FREEF( g_source_remove, vobject_refresh_timeout );
+		vobject_refresh_timeout = g_timeout_add( 20, 
+			(GSourceFunc) vobject_refresh_timeout_cb, NULL );
 	}
 
 	return( NULL );
@@ -197,14 +201,12 @@ vobject_iobject_destroy( iObject *iobject, vObject *vobject )
 void 
 vobject_link( vObject *vobject, iObject *iobject )
 {
+	vObjectClass *vobject_class = VOBJECT_GET_CLASS( vobject );
+
 	g_assert( !vobject->iobject );
 
-	vobject->iobject = iobject;
-
-	vobject->changed_sid = g_signal_connect( iobject, "changed", 
-		G_CALLBACK( vobject_iobject_changed ), vobject );
-	vobject->destroy_sid = g_signal_connect( iobject, "destroy", 
-		G_CALLBACK( vobject_iobject_destroy ), vobject );
+	if( vobject_class->link ) 
+		vobject_class->link( vobject, iobject );
 
 	/* Queue a refresh ... we always need at least one.
 	 */
@@ -248,6 +250,21 @@ vobject_finalize( GObject *gobject )
 static void
 vobject_real_refresh( vObject *vobject )
 {
+#ifdef DEBUG
+	printf( "vobject_real_refresh: %p %s\n", 
+		vobject, G_OBJECT_TYPE_NAME( vobject ) );
+#endif /*DEBUG*/
+}
+
+static void
+vobject_real_link( vObject *vobject, iObject *iobject )
+{
+	vobject->iobject = iobject;
+
+	vobject->changed_sid = g_signal_connect( iobject, "changed", 
+		G_CALLBACK( vobject_iobject_changed ), vobject );
+	vobject->destroy_sid = g_signal_connect( iobject, "destroy", 
+		G_CALLBACK( vobject_iobject_destroy ), vobject );
 }
 
 static void
@@ -268,6 +285,7 @@ vobject_class_init( vObjectClass *class )
 	/* Init default methods.
 	 */
 	class->refresh = vobject_real_refresh;
+	class->link = vobject_real_link;
 
 	/* Static init.
 	 */
