@@ -16,9 +16,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -58,8 +58,15 @@ typedef struct _vObjectClass {
 		refresh		refresh widgets (don't look at heap value,
 				look at model)
 
+		link		this vobject has been linked to an iobject
+
+				we also have View::link() -- vObject::link is
+				a lower-level link which is handy for views 
+				which are not Views, eg. toolkitbrowser
+
 	 */
 	void (*refresh)( vObject * );
+	void (*link)( vObject *, iObject * );
 } vObjectClass;
 
 void *vobject_refresh_queue( vObject *vobject );
